@@ -32,6 +32,7 @@ from pcluster.config.param_types import (
     SpotPriceParam,
 )
 from pcluster.config.validators import (
+    base_os_validator,
     cluster_validator,
     compute_instance_type_validator,
     dcv_enabled_validator,
@@ -455,15 +456,16 @@ CLUSTER = {
                 "validators": [ec2_key_pair_validator],
             }),
             ("base_os", {
-                "default": "alinux",
                 "cfn_param_mapping": "BaseOS",
                 "allowed_values": ["alinux", "alinux2", "ubuntu1604", "ubuntu1804", "centos6", "centos7"],
+                "validators": [base_os_validator],
+                "required": True,
             }),
             ("scheduler", {
-                "default": "sge",
                 "cfn_param_mapping": "Scheduler",
                 "allowed_values": ["awsbatch", "sge", "slurm", "torque"],
                 "validators": [scheduler_validator],
+                "required": True,
             }),
             ("placement_group", {
                 "cfn_param_mapping": "PlacementGroup",
